@@ -11,18 +11,24 @@ print.mitml.testConstraints <- function(x,...){
 
   # header
   cat("\nCall:\n", paste(deparse(cl)), sep="\n")
+  cat("\nHypothesis test calculated from",m,"imputed data sets. The following\nconstraints were specified:\n\n")
 
-  cat("\nHypothesis test calculated from",m,"imputed data sets. The following\nconstraints were specified:\n")
-  for(cc in cons) cat("\n",cc)
+  # print constraint table
+  est <- matrix(c(x$Qbar, sqrt(diag(x$T))), ncol=2)
+  colnames(est) <- c("Estimate", "Std. Error")
+  rownames(est) <- paste0(cons, ":")
 
-  cat("\n\nCombination method:",mth,"\n")
+  out <- .formatTable.helper(est)
+  for(i in 1:nrow(out)) cat("  ", out[i,],"\n")
 
-  # check for large values
+  cat("\nCombination method:",mth,"\n")
+
+  # print test table
   fmt <- c("%.3f","%.0f","%.3f","%.3f","%.3f")
-  fmt[test>=10^5] <- "%.3e"
+  fmt[test>=10^5] <- "%.3e" # large values
   out <- sprintf(fmt,test)
 
-  # print table
+  # table
   cat("\n")
   w <- max(sapply(c(out,colnames(test)),nchar))
   cat("  ",format(colnames(test),justify="right",width=w),"\n")
@@ -45,3 +51,16 @@ summary.mitml.testConstraints <- function(object,...){
   print.mitml.testConstraints(object,...)
 
 }
+
+.formatTable.helper <- function(x){
+
+  f <- sprintf("%.3f",x)
+  w <- max(sapply(c(colnames(x),f),nchar))
+  out <- matrix("",nrow(x)+1,ncol(x)+1)
+  out[,1] <- format(c("",rownames(x)))
+  out[1,-1] <- format(colnames(x),justify="right",width=w)
+  out[-1,-1] <- format(f,justify="right",width=w)
+
+  return(out)
+}
+
