@@ -5,18 +5,25 @@ print.mitml.testModels <- function(x,...){
   test <- x$test
   mth <- x$method
   use <- x$use
+  reml <- x$reml
   m <- x$m
   adj <- x$adj.df
   dfc <- x$df.com
 
+  # header
   cat("\nCall:\n", paste(deparse(cl)), sep="\n")
 
   cat("\nModel comparison calculated from",m,"imputed data sets.")
   cat("\nCombination method:",mth,
     if(mth=="D2"){paste("(",use,")",sep="")},"\n")
 
+  # check for large values
+  fmt <- c("%.3f","%.0f","%.3f","%.3f","%.3f")
+  fmt[test>=10^5] <- "%.3e"
+  out <- sprintf(fmt,test)
+
+  # print table
   cat("\n")
-  out <- sprintf(c("%.3f","%.0f","%.3f","%.3f","%.3f"),test)
   w <- max(sapply(c(out,colnames(test)),nchar))
   cat("  ",format(colnames(test),justify="right",width=w),"\n")
   cat("  ",format(out,justify="right",width=w),"\n")
@@ -26,9 +33,18 @@ print.mitml.testModels <- function(x,...){
               paste("df=[",paste(dfc,collapse=","),"]\ncomplete-data degrees of freedom.",sep=""))
       }else{"\nUnadjusted hypothesis test as appropriate in larger samples."},"\n")
   }
+  if(reml){
+  cat("\nModels originally fit with REML were automatically refit using ML.\n")
+  }
 
   cat("\n")
 
   invisible()
 }
 
+summary.mitml.testModels <- function(object,...){
+# summary method for objects of class mitml.testModels
+
+  print.mitml.testModels(object,...)
+
+}
